@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has action_status => (
@@ -130,7 +130,7 @@ SemanticWeb::Schema::Action - An action performed by a direct agent and indirect
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -164,7 +164,7 @@ A predicate for the L</action_status> attribute.
 
 =head2 C<agent>
 
-The direct performer or driver of the action (animate or inanimate). e.g.
+The direct performer or driver of the action (animate or inanimate). E.g.
 *John* wrote a book.
 
 A agent should be one of the following types:
@@ -187,7 +187,7 @@ C<endTime>
 
 The endTime of something. For a reserved event or service (e.g.
 FoodEstablishmentReservation), the time that it is expected to end. For
-actions that span a period of time, when the action was performed. e.g.
+actions that span a period of time, when the action was performed. E.g.
 John wrote a book from January to *December*. For media, including audio
 and video, it's the time offset of the end of a clip within a larger file.
 Note that Event uses startDate/endDate instead of startTime/endTime, even
@@ -224,7 +224,7 @@ A predicate for the L</error> attribute.
 
 =head2 C<instrument>
 
-The object that helped the agent perform the action. e.g. John wrote a book
+The object that helped the agent perform the action. E.g. John wrote a book
 with *a pen*.
 
 A instrument should be one of the following types:
@@ -266,7 +266,7 @@ A predicate for the L</location> attribute.
 
 The object upon which the action is carried out, whose state is kept intact
 or changed. Also known as the semantic roles patient, affected or undergoer
-(which change their state) or theme (which doesn't). e.g. John read *a
+(which change their state) or theme (which doesn't). E.g. John read *a
 book*.
 
 A object should be one of the following types:
@@ -283,7 +283,7 @@ A predicate for the L</object> attribute.
 
 =head2 C<participant>
 
-Other co-agents that participated in the action indirectly. e.g. John wrote
+Other co-agents that participated in the action indirectly. E.g. John wrote
 a book with *Steve*.
 
 A participant should be one of the following types:
@@ -322,7 +322,7 @@ A predicate for the L</provider> attribute.
 
 =head2 C<result>
 
-The result produced in the action. e.g. John wrote *a book*.
+The result produced in the action. E.g. John wrote *a book*.
 
 A result should be one of the following types:
 
@@ -342,7 +342,7 @@ C<startTime>
 
 The startTime of something. For a reserved event or service (e.g.
 FoodEstablishmentReservation), the time that it is expected to start. For
-actions that span a period of time, when the action was performed. e.g.
+actions that span a period of time, when the action was performed. E.g.
 John wrote a book from *January* to December. For media, including audio
 and video, it's the time offset of the start of a clip within a larger
 file. Note that Event uses startDate/endDate instead of startTime/endTime,
@@ -363,7 +363,7 @@ A predicate for the L</start_time> attribute.
 
 =head2 C<target>
 
-Indicates a target EntryPoint for an Action.
+Indicates a target EntryPoint, or url, for an Action.
 
 A target should be one of the following types:
 
@@ -371,6 +371,8 @@ A target should be one of the following types:
 
 =item C<InstanceOf['SemanticWeb::Schema::EntryPoint']>
 
+=item C<Str>
+
 =back
 
 =head2 C<_has_target>
