@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has blog_post => (
@@ -58,11 +58,11 @@ SemanticWeb::Schema::Blog - A [blog](https://en
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-A L<blog|https://en.wikipedia.org/wiki/Blog>, sometimes known as a "weblog". Note that the individual posts (L<SemanticWeb::Schema::BlogPosting>s) in a L<SemanticWeb::Schema::Blog> are often colloqually referred to by the same term.
+A L<blog|https://en.wikipedia.org/wiki/Blog>, sometimes known as a "weblog". Note that the individual posts (L<SemanticWeb::Schema::BlogPosting>s) in a L<SemanticWeb::Schema::Blog> are often colloquially referred to by the same term.
 
 =head1 ATTRIBUTES
 
