@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has area => (
@@ -122,7 +122,7 @@ SemanticWeb::Schema::BroadcastService - A delivery service through which content
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -189,8 +189,8 @@ A predicate for the L</broadcast_display_name> attribute.
 C<broadcastFrequency>
 
 The frequency used for over-the-air broadcasts. Numeric values or simple
-ranges e.g. 87-99. In addition a shortcut idiom is supported for frequences
-of AM and FM radio channels, e.g. "87 FM".
+ranges, e.g. 87-99. In addition a shortcut idiom is supported for
+frequences of AM and FM radio channels, e.g. "87 FM".
 
 A broadcast_frequency should be one of the following types:
 
@@ -211,7 +211,7 @@ A predicate for the L</broadcast_frequency> attribute.
 C<broadcastTimezone>
 
 The timezone in [ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)
-for which the service bases its broadcasts
+for which the service bases its broadcasts.
 
 A broadcast_timezone should be one of the following types:
 
