@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::DataDownload;
 
-# ABSTRACT: A dataset in downloadable form.
+# ABSTRACT: All or part of a [[Dataset]] in downloadable form
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has measurement_technique => (
@@ -38,15 +38,15 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::DataDownload - A dataset in downloadable form.
+SemanticWeb::Schema::DataDownload - All or part of a [[Dataset]] in downloadable form
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-A dataset in downloadable form.
+All or part of a L<SemanticWeb::Schema::Dataset> in downloadable form. 
 
 =head1 ATTRIBUTES
 
