@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has date_created => (
@@ -66,7 +66,7 @@ SemanticWeb::Schema::DataFeedItem - A single item within a larger data feed.
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -133,7 +133,7 @@ A predicate for the L</date_modified> attribute.
 =head2 C<item>
 
 An entity represented by an entry in a list or data feed (e.g. an 'artist'
-in a list of 'artists')â.
+in a list of 'artists').
 
 A item should be one of the following types:
 
