@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has catalog => (
@@ -106,7 +106,7 @@ SemanticWeb::Schema::Dataset - A body of structured information describing some
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -152,7 +152,12 @@ A predicate for the L</dataset_time_interval> attribute.
 =head2 C<distribution>
 
 A downloadable form of this dataset, at a specific location, in a specific
-format.
+format. This property can be repeated if different variations are
+available. There is no expectation that different downloadable
+distributions must contain exactly equivalent information (see also
+[DCAT](https://www.w3.org/TR/vocab-dcat-3/#Class:Distribution) on this
+point). Different distributions might include or exclude different subsets
+of the entire dataset, for example.
 
 A distribution should be one of the following types:
 
@@ -272,7 +277,7 @@ A predicate for the L</variable_measured> attribute.
 
 C<variablesMeasured>
 
-Originally named [[variablesMeasured]], The [[variableMeasured]] property can indicate (repeated as necessary) the  variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
+Originally named [[variablesMeasured]], the [[variableMeasured]] property can indicate (repeated as necessary) the  variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue.
 
 A variables_measured should be one of the following types:
 
