@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -34,12 +34,12 @@ SemanticWeb::Schema::DepartAction - The act of departing from a place
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-The act of departing from a place. An agent departs from an fromLocation
-for a destination, optionally with participants.
+The act of departing from a place. An agent departs from a fromLocation for
+a destination, optionally with participants.
 
 =head1 SEE ALSO
 
