@@ -6,7 +6,7 @@ package SemanticWeb::Schema::Drug;
 
 use Moo;
 
-extends qw/ SemanticWeb::Schema::Substance /;
+extends qw/ SemanticWeb::Schema::Product SemanticWeb::Schema::Substance /;
 
 
 use MooX::JSON_LD 'Drug';
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has active_ingredient => (
@@ -162,14 +162,6 @@ has legal_status => (
 
 
 
-has manufacturer => (
-    is        => 'rw',
-    predicate => '_has_manufacturer',
-    json_ld   => 'manufacturer',
-);
-
-
-
 has maximum_intake => (
     is        => 'rw',
     predicate => '_has_maximum_intake',
@@ -282,13 +274,13 @@ SemanticWeb::Schema::Drug - A chemical or biologic substance
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 A chemical or biologic substance, used as a medical therapy, that has a
 physiological effect on an organism. Here the term drug is used
-interchangeably with the term medicine although clinical knowledge make a
+interchangeably with the term medicine although clinical knowledge makes a
 clear difference between them.
 
 =head1 ATTRIBUTES
@@ -634,22 +626,6 @@ A legal_status should be one of the following types:
 
 A predicate for the L</legal_status> attribute.
 
-=head2 C<manufacturer>
-
-The manufacturer of the product.
-
-A manufacturer should be one of the following types:
-
-=over
-
-=item C<InstanceOf['SemanticWeb::Schema::Organization']>
-
-=back
-
-=head2 C<_has_manufacturer>
-
-A predicate for the L</manufacturer> attribute.
-
 =head2 C<maximum_intake>
 
 C<maximumIntake>
@@ -782,7 +758,7 @@ A predicate for the L</prescribing_info> attribute.
 
 C<prescriptionStatus>
 
-Indicates the status of drug prescription eg. local catalogs
+Indicates the status of drug prescription, e.g. local catalogs
 classifications or whether the drug is available by prescription or
 over-the-counter, etc.
 
