@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has application_deadline => (
@@ -226,7 +226,7 @@ SemanticWeb::Schema::EducationalOccupationalProgram - A program offered by an in
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -321,7 +321,7 @@ A predicate for the L</educational_credential_awarded> attribute.
 
 C<educationalProgramMode>
 
-Similar to courseMode, The medium or means of delivery of the program as a
+Similar to courseMode, the medium or means of delivery of the program as a
 whole. The value may either be a text label (e.g. "online", "onsite" or
 "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or
 a URL reference to a term from a controlled vocabulary (e.g.
@@ -535,7 +535,7 @@ A predicate for the L</program_prerequisites> attribute.
 C<programType>
 
 The type of educational or occupational program. For example, classroom,
-internship, alternance, etc..
+internship, alternance, etc.
 
 A program_type should be one of the following types:
 
