@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has address => (
@@ -98,7 +98,7 @@ SemanticWeb::Schema::GeoShape - The geographic shape of a place
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -188,7 +188,7 @@ A predicate for the L</circle> attribute.
 
 The elevation of a location ([WGS
 84](https://en.wikipedia.org/wiki/World_Geodetic_System)). Values may be of
-the form 'NUMBER UNIT_OF_MEASUREMENT' (e.g., '1,000 m', '3,200 ft') while
+the form 'NUMBER UNIT\_OF\_MEASUREMENT' (e.g., '1,000 m', '3,200 ft') while
 numbers alone should be assumed to be a value in meters.
 
 A elevation should be one of the following types:
