@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has geo_contains => (
@@ -114,7 +114,7 @@ SemanticWeb::Schema::GeospatialGeometry - (Eventually to be defined as) a supert
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -221,9 +221,9 @@ A predicate for the L</geo_crosses> attribute.
 C<geoDisjoint>
 
 Represents spatial relations in which two geometries (or the places they
-represent) are topologically disjoint: they have no point in common. They
-form a set of disconnected geometries." (a symmetric relationship, as
-defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM))
+represent) are topologically disjoint: "they have no point in common. They
+form a set of disconnected geometries." (A symmetric relationship, as
+defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)
 
 A geo_disjoint should be one of the following types:
 
@@ -248,7 +248,7 @@ represent) are topologically equal, as defined in
 [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). "Two geometries are
 topologically equal if their interiors intersect and no part of the
 interior or boundary of one geometry intersects the exterior of the other"
-(a symmetric relationship)
+(a symmetric relationship).
 
 A geo_equals should be one of the following types:
 
@@ -314,9 +314,9 @@ A predicate for the L</geo_overlaps> attribute.
 C<geoTouches>
 
 Represents spatial relations in which two geometries (or the places they
-represent) touch: they have at least one boundary point in common, but no
-interior points." (a symmetric relationship, as defined in
-[DE-9IM](https://en.wikipedia.org/wiki/DE-9IM) )
+represent) touch: "they have at least one boundary point in common, but no
+interior points." (A symmetric relationship, as defined in
+[DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)
 
 A geo_touches should be one of the following types:
 
