@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::Guide;
 
-# ABSTRACT: [[Guide]] is a page or article that recommend specific products or services
+# ABSTRACT: [[Guide]] is a page or article that recommends specific products or services
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has review_aspect => (
@@ -38,15 +38,15 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::Guide - [[Guide]] is a page or article that recommend specific products or services
+SemanticWeb::Schema::Guide - [[Guide]] is a page or article that recommends specific products or services
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-L<SemanticWeb::Schema::Guide> is a page or article that recommend specific products or services, or aspects of a thing for a user to consider. A L<SemanticWeb::Schema::Guide> may represent a Buying Guide and detail aspects of products or services for a user to consider. A L<SemanticWeb::Schema::Guide> may represent a Product Guide and recommend specific products or services. A L<SemanticWeb::Schema::Guide> may represent a Ranked List and recommend specific products or services with ranking.
+L<SemanticWeb::Schema::Guide> is a page or article that recommends specific products or services, or aspects of a thing for a user to consider. A L<SemanticWeb::Schema::Guide> may represent a Buying Guide and detail aspects of products or services for a user to consider. A L<SemanticWeb::Schema::Guide> may represent a Product Guide and recommend specific products or services. A L<SemanticWeb::Schema::Guide> may represent a Ranked List and recommend specific products or services with ranking.
 
 =head1 ATTRIBUTES
 
