@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has health_plan_cost_sharing => (
@@ -58,7 +58,7 @@ SemanticWeb::Schema::HealthPlanNetwork - A US-style health insurance plan networ
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -70,8 +70,7 @@ A US-style health insurance plan network.
 
 C<healthPlanCostSharing>
 
-Whether The costs to the patient for services under this network or
-formulary.
+The costs to the patient for services under this network or formulary.
 
 A health_plan_cost_sharing should be one of the following types:
 
@@ -90,7 +89,7 @@ A predicate for the L</health_plan_cost_sharing> attribute.
 C<healthPlanNetworkId>
 
 Name or unique ID of network. (Networks are often reused across different
-insurance plans).
+insurance plans.)
 
 A health_plan_network_id should be one of the following types:
 
