@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::House;
 
-# ABSTRACT: A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures (Source: Wikipedia
+# ABSTRACT: A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures (source: Wikipedia
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has number_of_rooms => (
@@ -38,16 +38,16 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::House - A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures (Source: Wikipedia
+SemanticWeb::Schema::House - A house is a building or structure that has the ability to be occupied for habitation by humans or other creatures (source: Wikipedia
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 =for html <p>A house is a building or structure that has the ability to be occupied
-for habitation by humans or other creatures (Source: Wikipedia, the free
+for habitation by humans or other creatures (source: Wikipedia, the free
 encyclopedia, see <a
 href="http://en.wikipedia.org/wiki/House">http://en.wikipedia.org/wiki/Hous
 e</a>).</p>
