@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has applicant_location_requirements => (
@@ -330,7 +330,7 @@ SemanticWeb::Schema::JobPosting - A listing that describes a job opening in a ce
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -614,7 +614,7 @@ A predicate for the L</experience_requirements> attribute.
 
 C<hiringOrganization>
 
-Organization offering the job position.
+Organization or Person offering the job position.
 
 A hiring_organization should be one of the following types:
 
@@ -622,6 +622,8 @@ A hiring_organization should be one of the following types:
 
 =item C<InstanceOf['SemanticWeb::Schema::Organization']>
 
+=item C<InstanceOf['SemanticWeb::Schema::Person']>
+
 =back
 
 =head2 C<_has_hiring_organization>
@@ -738,7 +740,7 @@ A predicate for the L</job_location> attribute.
 
 C<jobLocationType>
 
-A description of the job location (e.g TELECOMMUTE for telecommute jobs).
+A description of the job location (e.g. TELECOMMUTE for telecommute jobs).
 
 A job_location_type should be one of the following types:
 
@@ -879,9 +881,9 @@ A predicate for the L</responsibilities> attribute.
 
 C<salaryCurrency>
 
-The currency (coded using [ISO 4217](http://en.wikipedia.org/wiki/ISO_4217)
-) used for the main salary information in this job posting or for this
-employee.
+The currency (coded using [ISO
+4217](http://en.wikipedia.org/wiki/ISO_4217)) used for the main salary
+information in this job posting or for this employee.
 
 A salary_currency should be one of the following types:
 
