@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::LinkRole;
 
-# ABSTRACT: A Role that represents a Web link e
+# ABSTRACT: A Role that represents a Web link, e
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has in_language => (
@@ -46,19 +46,19 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::LinkRole - A Role that represents a Web link e
+SemanticWeb::Schema::LinkRole - A Role that represents a Web link, e
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-A Role that represents a Web link e.g. as expressed via the 'url' property.
-Its linkRelationship property can indicate URL-based and plain textual link
-types e.g. those in IANA link registry or others such as 'amphtml'. This
-structure provides a placeholder where details from HTML's link element can
-be represented outside of HTML, e.g. in JSON-LD feeds.
+A Role that represents a Web link, e.g. as expressed via the 'url'
+property. Its linkRelationship property can indicate URL-based and plain
+textual link types, e.g. those in IANA link registry or others such as
+'amphtml'. This structure provides a placeholder where details from HTML's
+link element can be represented outside of HTML, e.g. in JSON-LD feeds.
 
 =head1 ATTRIBUTES
 
