@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has item => (
@@ -66,7 +66,7 @@ SemanticWeb::Schema::ListItem - An list item, e
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -77,7 +77,7 @@ An list item, e.g. a step in a checklist or how-to description.
 =head2 C<item>
 
 An entity represented by an entry in a list or data feed (e.g. an 'artist'
-in a list of 'artists')â.
+in a list of 'artists').
 
 A item should be one of the following types:
 
@@ -131,7 +131,7 @@ A predicate for the L</position> attribute.
 
 C<previousItem>
 
-A link to the ListItem that preceeds the current one.
+A link to the ListItem that precedes the current one.
 
 A previous_item should be one of the following types:
 
