@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has amount => (
@@ -106,7 +106,7 @@ SemanticWeb::Schema::LoanOrCredit - A financial product for the loaning of an am
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -136,12 +136,12 @@ A predicate for the L</amount> attribute.
 =head2 C<currency>
 
 The currency in which the monetary amount is expressed. Use standard
-formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217)
+formats: [ISO 4217 currency format](http://en.wikipedia.org/wiki/ISO_4217),
 e.g. "USD"; [Ticker
 symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for
-cryptocurrencies e.g. "BTC"; well known names for [Local Exchange Tradings
+cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading
 Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system)
-(LETS) and other currency types e.g. "Ithaca HOUR".
+(LETS) and other currency types, e.g. "Ithaca HOUR".
 
 A currency should be one of the following types:
 
