@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has health_plan_network_id => (
@@ -58,7 +58,7 @@ SemanticWeb::Schema::MedicalOrganization - A medical organization (physical or n
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -72,7 +72,7 @@ clinic.
 C<healthPlanNetworkId>
 
 Name or unique ID of network. (Networks are often reused across different
-insurance plans).
+insurance plans.)
 
 A health_plan_network_id should be one of the following types:
 
