@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has additional_property => (
@@ -202,7 +202,7 @@ SemanticWeb::Schema::MerchantReturnPolicy - A MerchantReturnPolicy provides info
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -214,10 +214,10 @@ A MerchantReturnPolicy provides information about product return policies associ
 
 C<additionalProperty>
 
-A property-value pair representing an additional characteristics of the
-entitity, e.g. a product feature or another characteristic for which there
-is no matching property in schema.org. Note: Publishers should be aware
-that applications designed to use specific schema.org properties (e.g.
+A property-value pair representing an additional characteristic of the
+entity, e.g. a product feature or another characteristic for which there is
+no matching property in schema.org. Note: Publishers should be aware that
+applications designed to use specific schema.org properties (e.g.
 http://schema.org/width, http://schema.org/color, http://schema.org/gtin13,
 ...) will typically expect such data to be provided using those properties,
 rather than using the generic property/value mechanism. 
@@ -314,7 +314,7 @@ A predicate for the L</customer_remorse_return_shipping_fees_amount> attribute.
 
 C<inStoreReturnsOffered>
 
-Are in-store returns offered? (for more advanced return methods use the [[returnMethod]] property)
+Are in-store returns offered? (For more advanced return methods use the [[returnMethod]] property.)
 
 A in_store_returns_offered should be one of the following types:
 
@@ -484,7 +484,7 @@ A predicate for the L</restocking_fee> attribute.
 
 C<returnFees>
 
-The type of return fees for purchased products (for any return reason)
+The type of return fees for purchased products (for any return reason).
 
 A return_fees should be one of the following types:
 
@@ -557,7 +557,7 @@ A predicate for the L</return_policy_category> attribute.
 
 C<returnPolicyCountry>
 
-The country where the product has to be sent to for returns, for example "Ireland" using the [[name]] property of L<SemanticWeb::Schema::Country>. You can also provide the two-letter L<ISO 3166-1 alpha-2 country code|http://en.wikipedia.org/wiki/ISO_3166-1>. Note that this can be different from the country where the product was originally shipped from or sent too.
+The country where the product has to be sent to for returns, for example "Ireland" using the [[name]] property of L<SemanticWeb::Schema::Country>. You can also provide the two-letter L<ISO 3166-1 alpha-2 country code|http://en.wikipedia.org/wiki/ISO_3166-1>. Note that this can be different from the country where the product was originally shipped from or sent to.
 
 A return_policy_country should be one of the following types:
 
