@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has chemical_role => (
@@ -106,7 +106,7 @@ SemanticWeb::Schema::MolecularEntity - Any constitutionally or isotopically dist
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -240,7 +240,7 @@ C<monoisotopicMolecularWeight>
 The monoisotopic mass is the sum of the masses of the atoms in a molecule
 using the unbound, ground-state, rest mass of the principal (most abundant)
 isotope for each element instead of the isotopic average mass. Please
-include the units the form '&lt;Number&gt; &lt;unit&gt;', for example
+include the units in the form '&lt;Number&gt; &lt;unit&gt;', for example
 '770.230488 g/mol' or as '&lt;QuantitativeValue&gt;.
 
 A monoisotopic_molecular_weight should be one of the following types:
