@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has album_production_type => (
@@ -66,7 +66,7 @@ SemanticWeb::Schema::MusicAlbum - A collection of music tracks.
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -78,8 +78,8 @@ A collection of music tracks.
 
 C<albumProductionType>
 
-Classification of the album by it's type of content: soundtrack, live
-album, studio album, etc.
+Classification of the album by its type of content: soundtrack, live album,
+studio album, etc.
 
 A album_production_type should be one of the following types:
 
