@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::MusicAlbumProductionType;
 
-# ABSTRACT: Classification of the album by it's type of content: soundtrack
+# ABSTRACT: Classification of the album by its type of content: soundtrack
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -30,16 +30,16 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::MusicAlbumProductionType - Classification of the album by it's type of content: soundtrack
+SemanticWeb::Schema::MusicAlbumProductionType - Classification of the album by its type of content: soundtrack
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-Classification of the album by it's type of content: soundtrack, live
-album, studio album, etc.
+Classification of the album by its type of content: soundtrack, live album,
+studio album, etc.
 
 =head1 SEE ALSO
 
