@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -34,12 +34,12 @@ SemanticWeb::Schema::MusicReleaseFormatType - Format of this release (the type o
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-Format of this release (the type of recording media used, ie. compact disc,
-digital media, LP, etc.).
+Format of this release (the type of recording media used, i.e. compact
+disc, digital media, LP, etc.).
 
 =head1 SEE ALSO
 
