@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has delivery_time => (
@@ -26,6 +26,14 @@ has delivery_time => (
 
 
 
+has depth => (
+    is        => 'rw',
+    predicate => '_has_depth',
+    json_ld   => 'depth',
+);
+
+
+
 has does_not_ship => (
     is        => 'rw',
     predicate => '_has_does_not_ship',
@@ -34,6 +42,14 @@ has does_not_ship => (
 
 
 
+has height => (
+    is        => 'rw',
+    predicate => '_has_height',
+    json_ld   => 'height',
+);
+
+
+
 has shipping_destination => (
     is        => 'rw',
     predicate => '_has_shipping_destination',
@@ -50,6 +66,14 @@ has shipping_label => (
 
 
 
+has shipping_origin => (
+    is        => 'rw',
+    predicate => '_has_shipping_origin',
+    json_ld   => 'shippingOrigin',
+);
+
+
+
 has shipping_rate => (
     is        => 'rw',
     predicate => '_has_shipping_rate',
@@ -74,6 +98,22 @@ has transit_time_label => (
 
 
 
+has weight => (
+    is        => 'rw',
+    predicate => '_has_weight',
+    json_ld   => 'weight',
+);
+
+
+
+has width => (
+    is        => 'rw',
+    predicate => '_has_width',
+    json_ld   => 'width',
+);
+
+
+
 
 
 1;
@@ -90,17 +130,17 @@ SemanticWeb::Schema::OfferShippingDetails - OfferShippingDetails represents info
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 OfferShippingDetails represents information about shipping destinations.
 Multiple of these entities can be used to represent different shipping
 rates for different destinations: One entity for Alaska/Hawaii. A different
-one for continental US.A different one for all France. Multiple of these
+one for continental US. A different one for all France. Multiple of these
 entities can be used to represent different shipping costs and delivery
-times. Two entities that are identical but differ in rate and time: e.g.
-Cheaper and slower: $5 in 5-7days or Fast and expensive: $15 in 1-2 days.
+times. Two entities that are identical but differ in rate and time: E.g.
+Cheaper and slower: $5 in 5-7 days or Fast and expensive: $15 in 1-2 days.
 
 =head1 ATTRIBUTES
 
@@ -123,6 +163,24 @@ A delivery_time should be one of the following types:
 
 A predicate for the L</delivery_time> attribute.
 
+=head2 C<depth>
+
+The depth of the item.
+
+A depth should be one of the following types:
+
+=over
+
+=item C<InstanceOf['SemanticWeb::Schema::Distance']>
+
+=item C<InstanceOf['SemanticWeb::Schema::QuantitativeValue']>
+
+=back
+
+=head2 C<_has_depth>
+
+A predicate for the L</depth> attribute.
+
 =head2 C<does_not_ship>
 
 C<doesNotShip>
@@ -141,12 +199,30 @@ A does_not_ship should be one of the following types:
 
 A predicate for the L</does_not_ship> attribute.
 
+=head2 C<height>
+
+The height of the item.
+
+A height should be one of the following types:
+
+=over
+
+=item C<InstanceOf['SemanticWeb::Schema::Distance']>
+
+=item C<InstanceOf['SemanticWeb::Schema::QuantitativeValue']>
+
+=back
+
+=head2 C<_has_height>
+
+A predicate for the L</height> attribute.
+
 =head2 C<shipping_destination>
 
 C<shippingDestination>
 
 indicates (possibly multiple) shipping destinations. These can be defined
-in several ways e.g. postalCode ranges.
+in several ways, e.g. postalCode ranges.
 
 A shipping_destination should be one of the following types:
 
@@ -178,6 +254,24 @@ A shipping_label should be one of the following types:
 
 A predicate for the L</shipping_label> attribute.
 
+=head2 C<shipping_origin>
+
+C<shippingOrigin>
+
+Indicates the origin of a shipment, i.e. where it should be coming from.
+
+A shipping_origin should be one of the following types:
+
+=over
+
+=item C<InstanceOf['SemanticWeb::Schema::DefinedRegion']>
+
+=back
+
+=head2 C<_has_shipping_origin>
+
+A predicate for the L</shipping_origin> attribute.
+
 =head2 C<shipping_rate>
 
 C<shippingRate>
@@ -232,6 +326,40 @@ A transit_time_label should be one of the following types:
 
 A predicate for the L</transit_time_label> attribute.
 
+=head2 C<weight>
+
+The weight of the product or person.
+
+A weight should be one of the following types:
+
+=over
+
+=item C<InstanceOf['SemanticWeb::Schema::QuantitativeValue']>
+
+=back
+
+=head2 C<_has_weight>
+
+A predicate for the L</weight> attribute.
+
+=head2 C<width>
+
+The width of the item.
+
+A width should be one of the following types:
+
+=over
+
+=item C<InstanceOf['SemanticWeb::Schema::Distance']>
+
+=item C<InstanceOf['SemanticWeb::Schema::QuantitativeValue']>
+
+=back
+
+=head2 C<_has_width>
+
+A predicate for the L</width> attribute.
+
 =head1 SEE ALSO
 
 L<SemanticWeb::Schema::StructuredValue>
