@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has accepted_offer => (
@@ -210,7 +210,7 @@ SemanticWeb::Schema::Order - An order is a confirmation of a transaction (a rece
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -355,11 +355,11 @@ A predicate for the L</discount_code> attribute.
 C<discountCurrency>
 
 The currency of the discount. Use standard formats: [ISO 4217 currency
-format](http://en.wikipedia.org/wiki/ISO_4217) e.g. "USD"; [Ticker
+format](http://en.wikipedia.org/wiki/ISO_4217), e.g. "USD"; [Ticker
 symbol](https://en.wikipedia.org/wiki/List_of_cryptocurrencies) for
-cryptocurrencies e.g. "BTC"; well known names for [Local Exchange Tradings
+cryptocurrencies, e.g. "BTC"; well known names for [Local Exchange Trading
 Systems](https://en.wikipedia.org/wiki/Local_exchange_trading_system)
-(LETS) and other currency types e.g. "Ithaca HOUR".
+(LETS) and other currency types, e.g. "Ithaca HOUR".
 
 A discount_currency should be one of the following types:
 
@@ -377,7 +377,8 @@ A predicate for the L</discount_currency> attribute.
 
 C<isGift>
 
-Was the offer accepted as a gift for someone other than the buyer.
+Indicates whether the offer was accepted as a gift for someone other than
+the buyer.
 
 A is_gift should be one of the following types:
 
