@@ -2,7 +2,7 @@ use utf8;
 
 package SemanticWeb::Schema::Periodical;
 
-# ABSTRACT: A publication in any medium issued in successive parts bearing numerical or chronological designations and intended
+# ABSTRACT: A publication in any medium issued in successive parts bearing numerical or chronological designations and intended to continue indefinitely
 
 use Moo;
 
@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -30,17 +30,17 @@ __END__
 
 =head1 NAME
 
-SemanticWeb::Schema::Periodical - A publication in any medium issued in successive parts bearing numerical or chronological designations and intended
+SemanticWeb::Schema::Periodical - A publication in any medium issued in successive parts bearing numerical or chronological designations and intended to continue indefinitely
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 A publication in any medium issued in successive parts bearing numerical or
-chronological designations and intended, such as a magazine, scholarly
-journal, or newspaper to continue indefinitely. See also [blog
+chronological designations and intended to continue indefinitely, such as a
+magazine, scholarly journal, or newspaper. See also [blog
 post](http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.
 html).
 
