@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has additional_property => (
@@ -394,7 +394,7 @@ SemanticWeb::Schema::Place - Entities that have a somewhat fixed
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -406,10 +406,10 @@ Entities that have a somewhat fixed, physical extension.
 
 C<additionalProperty>
 
-A property-value pair representing an additional characteristics of the
-entitity, e.g. a product feature or another characteristic for which there
-is no matching property in schema.org. Note: Publishers should be aware
-that applications designed to use specific schema.org properties (e.g.
+A property-value pair representing an additional characteristic of the
+entity, e.g. a product feature or another characteristic for which there is
+no matching property in schema.org. Note: Publishers should be aware that
+applications designed to use specific schema.org properties (e.g.
 http://schema.org/width, http://schema.org/color, http://schema.org/gtin13,
 ...) will typically expect such data to be provided using those properties,
 rather than using the generic property/value mechanism. 
@@ -727,9 +727,9 @@ A predicate for the L</geo_crosses> attribute.
 C<geoDisjoint>
 
 Represents spatial relations in which two geometries (or the places they
-represent) are topologically disjoint: they have no point in common. They
-form a set of disconnected geometries." (a symmetric relationship, as
-defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM))
+represent) are topologically disjoint: "they have no point in common. They
+form a set of disconnected geometries." (A symmetric relationship, as
+defined in [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)
 
 A geo_disjoint should be one of the following types:
 
@@ -754,7 +754,7 @@ represent) are topologically equal, as defined in
 [DE-9IM](https://en.wikipedia.org/wiki/DE-9IM). "Two geometries are
 topologically equal if their interiors intersect and no part of the
 interior or boundary of one geometry intersects the exterior of the other"
-(a symmetric relationship)
+(a symmetric relationship).
 
 A geo_equals should be one of the following types:
 
@@ -820,9 +820,9 @@ A predicate for the L</geo_overlaps> attribute.
 C<geoTouches>
 
 Represents spatial relations in which two geometries (or the places they
-represent) touch: they have at least one boundary point in common, but no
-interior points." (a symmetric relationship, as defined in
-[DE-9IM](https://en.wikipedia.org/wiki/DE-9IM) )
+represent) touch: "they have at least one boundary point in common, but no
+interior points." (A symmetric relationship, as defined in
+[DE-9IM](https://en.wikipedia.org/wiki/DE-9IM).)
 
 A geo_touches should be one of the following types:
 
