@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has additional_property => (
@@ -90,7 +90,7 @@ SemanticWeb::Schema::QuantitativeValue - A point value or interval for product c
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -102,10 +102,10 @@ version v14.0.0
 
 C<additionalProperty>
 
-A property-value pair representing an additional characteristics of the
-entitity, e.g. a product feature or another characteristic for which there
-is no matching property in schema.org. Note: Publishers should be aware
-that applications designed to use specific schema.org properties (e.g.
+A property-value pair representing an additional characteristic of the
+entity, e.g. a product feature or another characteristic for which there is
+no matching property in schema.org. Note: Publishers should be aware that
+applications designed to use specific schema.org properties (e.g.
 http://schema.org/width, http://schema.org/color, http://schema.org/gtin13,
 ...) will typically expect such data to be provided using those properties,
 rather than using the generic property/value mechanism. 
@@ -210,11 +210,11 @@ For L<SemanticWeb::Schema::QuantitativeValue> and L<SemanticWeb::Schema::Monetar
 
 =item *
 
-For L<SemanticWeb::Schema::PropertyValue>, it can be 'Text;', 'Number', 'Boolean', or 'StructuredValue'.
+For L<SemanticWeb::Schema::PropertyValue>, it can be 'Text', 'Number', 'Boolean', or 'StructuredValue'.
 
 =item *
 
-Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similiar Unicode symbols.
+Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.
 
 =item *
 
