@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has associated_claim_review => (
@@ -106,7 +106,7 @@ SemanticWeb::Schema::Review - A review of an item - for example
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -190,7 +190,12 @@ A predicate for the L</item_reviewed> attribute.
 
 C<negativeNotes>
 
-Indicates, in the context of a L<SemanticWeb::Schema::Review> (e.g. framed as 'pro' vs 'con' considerations), negative considerations - either as unstructured text, or a list.
+Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside [[positiveNotes]]). For symmetry 
+
+In the case of a L<SemanticWeb::Schema::Review>, the property describes the [[itemReviewed]] from the perspective of the review; in the case of a L<SemanticWeb::Schema::Product>, the product itself is being described. Since product descriptions 
+tend to emphasise positive claims, it may be relatively unusual to find [[negativeNotes]] used in this way. Nevertheless for the sake of symmetry, [[negativeNotes]] can be used on L<SemanticWeb::Schema::Product>.
+
+The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most negative is at the beginning of the list).
 
 A negative_notes should be one of the following types:
 
@@ -214,7 +219,11 @@ A predicate for the L</negative_notes> attribute.
 
 C<positiveNotes>
 
-Indicates, in the context of a L<SemanticWeb::Schema::Review> (e.g. framed as 'pro' vs 'con' considerations), positive considerations - either as unstructured text, or a list.
+Provides positive considerations regarding something, for example product highlights or (alongside [[negativeNotes]]) pro/con lists for reviews.
+
+In the case of a L<SemanticWeb::Schema::Review>, the property describes the [[itemReviewed]] from the perspective of the review; in the case of a L<SemanticWeb::Schema::Product>, the product itself is being described.
+
+The property values can be expressed either as unstructured text (repeated as necessary), or if ordered, as a list (in which case the most positive is at the beginning of the list).
 
 A positive_notes should be one of the following types:
 
