@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -34,12 +34,12 @@ SemanticWeb::Schema::Room - A room is a distinguishable space within a structure
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 =for html <p>A room is a distinguishable space within a structure, usually separated
-from other spaces by interior walls. (Source: Wikipedia, the free
+from other spaces by interior walls (source: Wikipedia, the free
 encyclopedia, see <a
 href="http://en.wikipedia.org/wiki/Room">http://en.wikipedia.org/wiki/Room<
 /a>). <br /><br /> See also the <a href="/docs/hotels.html">dedicated
