@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has code_repository => (
@@ -90,7 +90,7 @@ SemanticWeb::Schema::SoftwareSourceCode - Computer programming source code
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -104,7 +104,7 @@ code snippet samples, scripts, templates.
 C<codeRepository>
 
 Link to the repository where the un-compiled, human readable code and
-related code is located (SVN, github, CodePlex).
+related code is located (SVN, GitHub, CodePlex).
 
 A code_repository should be one of the following types:
 
@@ -159,8 +159,8 @@ A predicate for the L</programming_language> attribute.
 
 =head2 C<runtime>
 
-Runtime platform or script interpreter dependencies (Example - Java v1,
-Python2.3, .Net Framework 3.0).
+Runtime platform or script interpreter dependencies (example: Java v1,
+Python 2.3, .NET Framework 3.0).
 
 A runtime should be one of the following types:
 
@@ -178,8 +178,8 @@ A predicate for the L</runtime> attribute.
 
 C<runtimePlatform>
 
-Runtime platform or script interpreter dependencies (Example - Java v1,
-Python2.3, .Net Framework 3.0).
+Runtime platform or script interpreter dependencies (example: Java v1,
+Python 2.3, .NET Framework 3.0).
 
 A runtime_platform should be one of the following types:
 
