@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 
@@ -34,11 +34,11 @@ SemanticWeb::Schema::Statement - A statement about something
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
-A statement about something, for example a fun or interesting fact. If known, the main entity this statement is about, can be indicated using mainEntity. For more formal claims (e.g. in Fact Checking), consider using L<SemanticWeb::Schema::Claim> instead. Use the [[text]] property to capture the text of the statement.
+A statement about something, for example a fun or interesting fact. If known, the main entity this statement is about can be indicated using mainEntity. For more formal claims (e.g. in Fact Checking), consider using L<SemanticWeb::Schema::Claim> instead. Use the [[text]] property to capture the text of the statement.
 
 =head1 SEE ALSO
 
