@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has child_taxon => (
@@ -66,7 +66,7 @@ SemanticWeb::Schema::Taxon - A set of organisms asserted to represent a natural
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -138,8 +138,8 @@ A predicate for the L</parent_taxon> attribute.
 C<taxonRank>
 
 The taxonomic rank of this taxon given preferably as a URI from a
-controlled vocabulary â (typically the ranks from TDWG TaxonRank ontology
-or equivalent Wikidata URIs).
+controlled vocabulary â typically the ranks from TDWG TaxonRank ontology
+or equivalent Wikidata URIs.
 
 A taxon_rank should be one of the following types:
 
