@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has available_language => (
@@ -50,7 +50,7 @@ SemanticWeb::Schema::TouristAttraction - A tourist attraction
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,7 @@ A tourist attraction.  In principle any Thing can be a L<SemanticWeb::Schema::To
 
 C<availableLanguage>
 
-A language someone may use with or at the item, service or place. Please use one of the language codes from the L<IETF BCP 47 standard|http://tools.ietf.org/html/bcp47>. See also [[inLanguage]]
+A language someone may use with or at the item, service or place. Please use one of the language codes from the L<IETF BCP 47 standard|http://tools.ietf.org/html/bcp47>. See also [[inLanguage]].
 
 A available_language should be one of the following types:
 
@@ -82,7 +82,7 @@ A predicate for the L</available_language> attribute.
 
 C<touristType>
 
-Attraction suitable for type(s) of tourist. eg. Children, visitors from a
+Attraction suitable for type(s) of tourist. E.g. children, visitors from a
 particular country, etc. 
 
 A tourist_type should be one of the following types:
