@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has includes_attraction => (
@@ -50,12 +50,12 @@ SemanticWeb::Schema::TouristDestination - A tourist destination
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
 A tourist destination. In principle any L<SemanticWeb::Schema::Place> can be a L<SemanticWeb::Schema::TouristDestination> from a L<SemanticWeb::Schema::City>, Region or L<SemanticWeb::Schema::Country> to an L<SemanticWeb::Schema::AmusementPark> or L<SemanticWeb::Schema::Hotel>. This Type can be used on its own to describe a general L<SemanticWeb::Schema::TouristDestination>, or be used as an [[additionalType]] to add tourist relevant properties to any other L<SemanticWeb::Schema::Place>.  A L<SemanticWeb::Schema::TouristDestination> is defined as a L<SemanticWeb::Schema::Place> that contains, or is colocated with, one or more L<SemanticWeb::Schema::TouristAttraction>s, often linked by a similar theme or interest to a particular [[touristType]]. The L<UNWTO|http://www2.unwto.org/> defines Destination (main destination of a tourism trip) as the place visited that is central to the decision to take the trip.
-  (See examples below).
+  (See examples below.)
 
 =head1 ATTRIBUTES
 
@@ -81,7 +81,7 @@ A predicate for the L</includes_attraction> attribute.
 
 C<touristType>
 
-Attraction suitable for type(s) of tourist. eg. Children, visitors from a
+Attraction suitable for type(s) of tourist. E.g. children, visitors from a
 particular country, etc. 
 
 A tourist_type should be one of the following types:
