@@ -15,7 +15,7 @@ use Ref::Util qw/ is_plain_hashref /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v14.0.0';
+our $VERSION = 'v15.0.0';
 
 
 has acceleration_time => (
@@ -354,7 +354,7 @@ SemanticWeb::Schema::Vehicle - A vehicle is a device that is designed or used to
 
 =head1 VERSION
 
-version v14.0.0
+version v15.0.0
 
 =head1 DESCRIPTION
 
@@ -865,7 +865,7 @@ A predicate for the L</production_date> attribute.
 
 C<purchaseDate>
 
-The date the item e.g. vehicle was purchased by the current owner.
+The date the item, e.g. vehicle, was purchased by the current owner.
 
 A purchase_date should be one of the following types:
 
@@ -903,7 +903,7 @@ A predicate for the L</seating_capacity> attribute.
 
 =head2 C<speed>
 
-The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by [[maxValue]] should be the maximum speed achievable under regular conditions.
+The speed range of the vehicle. If the vehicle is powered by an engine, the upper limit of the speed range (indicated by [[maxValue]]) should be the maximum speed achievable under regular conditions.
 
 Typical unit code(s): KMH for km/h, HM for mile per hour (0.447 04 m/s), KNT for knot
 
@@ -962,7 +962,7 @@ A predicate for the L</stupid_property> attribute.
 
 C<tongueWeight>
 
-The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR)
+The permitted vertical load (TWR) of a trailer attached to the vehicle. Also referred to as Tongue Load Rating (TLR) or Vertical Load Rating (VLR).
 
 Typical unit code(s): KGM for kilogram, LBR for pound
 
